@@ -1,5 +1,5 @@
 package Lingua::Anagrams;
-$Lingua::Anagrams::VERSION = '0.018';
+$Lingua::Anagrams::VERSION = '0.019';
 # ABSTRACT: pure Perl anagram finder
 
 use strict;
@@ -90,7 +90,6 @@ sub _trieify {
     my $base = [];
     my @known;
     for my $word (@$words) {
-        next unless length( $word // '' );
         my @chars = map { ord($_) - $offset } split //, $word;
         _learn( \@known, \@chars );
         _add( $base, \@chars, $word, $translator );
@@ -175,21 +174,9 @@ sub anagrams {
     local ( $limit, $cleaner ) = @$self{qw(limit clean)};
     $cleaner->($phrase);
     return () unless length $phrase;
-    my ( $sort, $min );
-
-    if ( exists $opts{sorted} ) {
-        $sort = $opts{sorted};
-    }
-    else {
-        $sort = $self->{sorted};
-    }
-    if ( exists $opts{min} ) {
-        $min = $opts{min};
-    }
-    else {
-        $min = $self->{min};
-    }
-    my $i = $opts{start_list} // 0;
+    my $sort = $opts{sorted}     // $self->{sorted};
+    my $min  = $opts{min}        // $self->{min};
+    my $i    = $opts{start_list} // 0;
     my @pairs = @{ $self->{tries} };
     if ($i) {
         die "impossible index for start list: $i" unless defined $pairs[$i];
@@ -278,9 +265,7 @@ sub _super_iterator {
             redo if $c{$key}++;
         }
         $rv = [ @$translator[@$rv] ];
-        if ( $opts->{sorted} ) {
-            $rv = [ sort @$rv ];
-        }
+        $rv = [ sort @$rv ] if $opts->{sorted};
         $rv;
     };
 }
@@ -292,7 +277,7 @@ sub _iterator {
     $total += $_ for @$counts[@indices];
     my @t = @$tries;
     my $i;
-    my $s = sub {
+    sub {
         my $rv;
         {
             unless ($i) {
@@ -316,14 +301,13 @@ sub _iterator {
         }
         $rv;
     };
-    $s;
 }
 
 # iterator that actually walks tries looking for anagrams
 sub _sub_iterator {
     my ( $tries, $words, $opts ) = @_;
     my @pairs = @$words;
-    return sub {
+    sub {
         {
             return unless @pairs;
             if ( $opts->{random} ) {
@@ -354,7 +338,7 @@ sub _sub_iterator {
                 shift @pairs;
                 redo;
             }
-            return [ $w, @$remainder ];
+            [ $w, @$remainder ];
         }
     };
 }
@@ -487,10 +471,8 @@ sub _anagramize {
             }
         }
         my %seen;
-        @anagrams = map {
-            $seen{ join ' ', sort { $a <=> $b } @$_ }++
-              ? ()
-              : $_
+        @anagrams = grep {
+            !$seen{ join ' ', sort { $a <=> $b } @$_ }++
         } @anagrams;
     }
     $cache{$key} = \@anagrams if $key;
@@ -552,7 +534,7 @@ Lingua::Anagrams - pure Perl anagram finder
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -771,7 +753,7 @@ Returns the number of word lists being used by the anagramizer.
 =head1 SOME CLEVER BITS
 
 One trick I use to speed things up is to convert all characters to integers
-immediately. If you're using integers, you can treat arrays are really fast
+immediately. If you're using integers, you can treat arrays as really fast
 hashes.
 
 The natural way to walk the trie is with recursion, but I use a stack and a loop
@@ -788,7 +770,7 @@ reached a dead end and we should give up.
 Similarly, if we B<do> touch every character in a particular step we can collect
 all the words extracted which touch that character and descend only into the
 remaining possibilities for those character counts because the other words one
-might exctract are necessarily contained in the remaining character counts.
+might extract are necessarily contained in the remaining character counts.
 
 The dynamic programming bit consists of memoizing the anagram lists keyed to the
 character counts so we never extract the anagrams for a particular set of counts
